@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -18,8 +18,9 @@
 #include "dnd.h"
 #include "dupe.h"
 #include "filelist.h"
-#include "img-main.h"
 #include "img-view.h"
+#include "layout.h"
+#include "layout_image.h"
 #include "menu.h"
 #include "utilops.h"
 #include "ui_clist_edit.h"
@@ -548,7 +549,7 @@ static void collection_table_popup_view_cb(GtkWidget *widget, gpointer data)
 
 	if (ct->mouse_current && g_list_find(ct->cd->list, ct->mouse_current))
 		{
-		main_image_change_to_from_collection(ct->cd, ct->mouse_current);
+		layout_image_set_collection(NULL, ct->cd, ct->mouse_current);
 		}
 }
 
@@ -583,7 +584,7 @@ static void collection_table_popup_add_filelist_cb(GtkWidget *widget, gpointer d
 	CollectTable *ct = data;
 	GList *list;
 
-	list = file_get_complete_list();
+	list = layout_list(NULL);
 
 	if (list)
 		{
@@ -636,7 +637,7 @@ static GtkWidget *collection_table_popup_menu(CollectTable *ct, gint over_icon)
 		menu_item_add(menu, _("Delete..."), collection_table_popup_delete_cb, ct);
 		menu_item_add_divider(menu);
 		}
-	submenu_add_sort(menu, collection_table_popup_sort_cb, ct, FALSE, TRUE);
+	submenu_add_sort(menu, collection_table_popup_sort_cb, ct, FALSE, TRUE, FALSE, 0);
 	menu_item_add_divider(menu);
 	menu_item_add(menu, _("Save collection"), collection_table_popup_save_cb, ct);
 	menu_item_add(menu, _("Save collection as..."), collection_table_popup_save_as_cb, ct);
@@ -1190,7 +1191,7 @@ static void clist_button_press(GtkWidget *widget, GdkEventButton *bevent, gpoint
 			if (!info) return;
 			if (bevent->type == GDK_2BUTTON_PRESS)
 				{
-				main_image_change_to_from_collection(ct->cd, info);
+				layout_image_set_collection(NULL, ct->cd, info);
 				return;
 				}
 
@@ -1831,11 +1832,6 @@ static GtkWidget *confirm_dir_list(CollectTable *ct, GList *list)
  * dnd
  *-------------------------------------------------------------------
  */
-enum {
-	TARGET_APP_COLLECTION_MEMBER,
-	TARGET_URI_LIST,
-	TARGET_TEXT_PLAIN
-};
 
 static GtkTargetEntry collection_drag_types[] = {
 	{ "application/x-gqview-collection-member", 0, TARGET_APP_COLLECTION_MEMBER },
