@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -17,8 +17,9 @@
 #include "collect-io.h"
 #include "collect-table.h"
 #include "filelist.h"
-#include "img-main.h"
 #include "img-view.h"
+#include "layout.h"
+#include "layout_image.h"
 #include "thumb.h"
 #include "utilops.h"
 #include "ui_clist_edit.h"
@@ -775,7 +776,7 @@ static gint collection_window_keypress(GtkWidget *widget, GdkEventKey *event, gp
 				stop_signal = TRUE;
 				break;
 			case 'L': case 'l':
-				list = file_get_complete_list();
+				list = layout_list(NULL);
 				if (list)
 					{
 					collection_table_add_path_list(cw->table, list);
@@ -812,7 +813,7 @@ static gint collection_window_keypress(GtkWidget *widget, GdkEventKey *event, gp
 		switch (event->keyval)
 			{
 			case GDK_Return: case GDK_KP_Enter:
-				main_image_change_to_from_collection(cw->cd,
+				layout_image_set_collection(NULL, cw->cd,
 					collection_table_get_focus_info(cw->table));
 				stop_signal = TRUE;
 				break;
