@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -19,8 +19,9 @@
 #include "dnd.h"
 #include "filelist.h"
 #include "image-load.h"
-#include "img-main.h"
 #include "img-view.h"
+#include "layout.h"
+#include "layout_image.h"
 #include "menu.h"
 #include "thumb.h"
 #include "utilops.h"
@@ -1193,7 +1194,7 @@ static void dupe_menu_view(DupeWindow *dw, DupeItem *di, gint new_window)
 			}
 		else
 			{
-			main_image_change_to_from_collection(di->collection, di->info);
+			layout_image_set_collection(NULL, di->collection, di->info);
 			}
 		}
 	else
@@ -1204,7 +1205,7 @@ static void dupe_menu_view(DupeWindow *dw, DupeItem *di, gint new_window)
 			}
 		else
 			{
-			filelist_change_to_full_path(di->path);
+			layout_image_set_path(NULL, di->path);
 			}
 		}
 }
@@ -1277,7 +1278,7 @@ static void dupe_window_append_file_list(DupeWindow *dw, gint on_second)
 
 	dw->second_drop = (dw->second_set && on_second);
 
-	list = file_get_complete_list();
+	list = layout_list(NULL);
 	dupe_window_add_files(dw, list, FALSE);
 	path_list_free(list);
 }
@@ -2203,12 +2204,6 @@ static GtkWidget *dupe_confirm_dir_list(DupeWindow *dw, GList *list)
  *-------------------------------------------------------------------
  */
 
-enum {
-        TARGET_APP_COLLECTION_MEMBER,
-        TARGET_URI_LIST,
-        TARGET_TEXT_PLAIN
-};
-
 static GtkTargetEntry dupe_drag_types[] = {
         { "text/uri-list", 0, TARGET_URI_LIST },
         { "text/plain", 0, TARGET_TEXT_PLAIN }
