@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -14,43 +14,6 @@
 #include "logo.xpm"
 #include "icons/img_unknown.xpm"
 
-/* image */
-ImageWindow *main_image = NULL;
-
-/* main window */
-GtkWidget *mainwindow;
-GtkWidget *mainwindow_hbox;
-GtkWidget *mainwindow_vbox;
-GtkAccelGroup *mainwindow_accel_grp;
-
-GtkWidget *info_box = NULL;
-GtkWidget *info_progress_bar;
-GtkWidget *info_status;
-GtkWidget *info_details;
-GtkWidget *info_zoom;
-
-/* full screen */
-ImageWindow *normal_image = NULL;
-ImageWindow *full_screen_image = NULL;
-GtkWidget *full_screen_window = NULL;
-
-/* tools floating window */
-GtkWidget *toolwindow = NULL;
-
-/* tools */
-GtkWidget *tool_vbox;
-
-GtkWidget *path_entry;
-GtkWidget *history_menu;
-
-GtkWidget *dir_clist;
-GtkWidget *file_clist;
-
-GtkItemFactory *gqview_fact;
-
-GtkWidget *thumb_button;
-
-gchar *current_path = NULL;
 
 GList *filename_filter = NULL;
 
@@ -65,7 +28,8 @@ gint float_window_h = 350;
 gint float_window_x = 0;
 gint float_window_y = 0;
 
-gint main_window_vdivider_pos = 100;
+gint window_hdivider_pos = -1;
+gint window_vdivider_pos = 100;
 
 gint save_window_positions = FALSE;
 gint tools_float = FALSE;
@@ -136,4 +100,11 @@ gint debug = FALSE;
 const char **logo = (const char **)logo_xpm;
 const char **img_unknown = (const char **)img_unknown_xpm;
 
+/* layout */
+gchar *layout_order = NULL;
+gint layout_style = 0;
 
+gint layout_view_icons = FALSE;
+gint layout_view_tree = FALSE;
+
+gint tree_descend_subdirs = FALSE;
