@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -86,44 +86,6 @@
  * it is easier to define them here.
  */
 
-/* image */
-extern ImageWindow *main_image;
-
-/* main window */
-extern GtkWidget *mainwindow;
-extern GtkWidget *mainwindow_hbox;
-extern GtkWidget *mainwindow_vbox;
-extern GtkAccelGroup *mainwindow_accel_grp;
-
-extern GtkWidget *info_box;
-extern GtkWidget *info_progress_bar;
-extern GtkWidget *info_status;
-extern GtkWidget *info_details;
-extern GtkWidget *info_zoom;
-
-/* full screen */
-extern ImageWindow *normal_image;
-extern ImageWindow *full_screen_image;
-extern GtkWidget *full_screen_window;
-
-/* tools floating window */
-extern GtkWidget *toolwindow;
-
-/* tools */
-extern GtkWidget *tool_vbox;
-
-extern GtkWidget *path_entry;
-extern GtkWidget *history_menu;
-
-extern GtkWidget *dir_clist;
-extern GtkWidget *file_clist;
-
-extern GtkItemFactory *gqview_fact;
-
-extern GtkWidget *thumb_button;
-
-extern gchar *current_path;
-
 extern GList *filename_filter;
 
 /* -- options -- */
@@ -137,7 +99,8 @@ extern gint float_window_h;
 extern gint float_window_x;
 extern gint float_window_y;
 
-extern gint main_window_vdivider_pos;
+extern gint window_hdivider_pos;
+extern gint window_vdivider_pos;
 
 extern gint save_window_positions;
 extern gint tools_float;
@@ -207,6 +170,15 @@ extern gint place_dialogs_under_mouse;
 extern const char **logo;
 extern const char **img_unknown;
 
+/* layout */
+extern gchar *layout_order;
+extern gint layout_style;
+
+extern gint layout_view_icons;
+extern gint layout_view_tree;
+
+extern gint tree_descend_subdirs;
+
 /*
  *----------------------------------------------------------------------------
  * main.c
@@ -224,9 +196,8 @@ gfloat get_zoom_increment(void);
 void help_window_show(const gchar *key);
 
 void start_editor_from_file(gint n, const gchar *path);
-void start_editor_from_image(gint n);
 void start_editor_from_path_list(gint n, GList *list);
-void start_editor_from_list(gint n);
+
 void keyboard_scroll_calc(gint *x, gint *y, GdkEventKey *event);
 gint key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data);
 void exit_gqview(void);
