@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -239,6 +239,15 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 		case '4':
 			image_zoom_set(imd, 4.0);
 			break;
+		case '7':
+			image_zoom_set(imd, -4.0);
+			break;
+		case '8':
+			image_zoom_set(imd, -3.0);
+			break;
+		case '9':
+			image_zoom_set(imd, -2.0);
+			break;
 		case 'S': case 's':
 			if (vw->ss)
 				view_slideshow_stop(vw);
@@ -843,8 +852,3 @@ static GtkWidget *view_popup_menu(ViewWindow *vw)
 	return menu;
 }
 
-
-
-
-
-
