@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -15,13 +15,13 @@
 #include "collect.h"
 #include "dnd.h"
 #include "filelist.h"
-#include "img-main.h"
+#include "layout.h"
+#include "layout_image.h"
 #include "menu.h"
 #include "preferences.h"
 #include "rcfile.h"
 #include "slideshow.h"
 #include "utilops.h"
-#include "window.h"
 #include "ui_help.h"
 #include "ui_fileops.h"
 #include "ui_tabcomp.h"
@@ -37,6 +37,7 @@
  * misc (public)
  *-----------------------------------------------------------------------------
  */ 
+
 typedef struct _WindowIconData WindowIconData;
 struct _WindowIconData
 {
@@ -141,16 +142,14 @@ void help_window_show(const gchar *key)
 void start_editor_from_file(gint n, const gchar *path)
 {
 	gchar *cmd;
+
 	if (!path) return;
+
 	cmd = g_strdup_printf("%s \"%s\" &", editor_command[n], path);
 	if (debug) printf(_("GQview running: %s\n"),cmd);
 	system(cmd);
-	g_free(cmd);
-}
 
-void start_editor_from_image(gint n)
-{
-	start_editor_from_file(n, main_image_get_path());
+	g_free(cmd);
 }
 
 void start_editor_from_path_list(gint n, GList *list)
@@ -163,7 +162,7 @@ void start_editor_from_path_list(gint n, GList *list)
 
 	work = list;
 	cmd = g_strconcat(editor_command[n], " ", NULL);
-	while(work)
+	while (work)
 		{
 		buf = cmd;
 		cmd = g_strconcat(buf, "\"", work->data, "\" ", NULL);
@@ -175,19 +174,10 @@ void start_editor_from_path_list(gint n, GList *list)
 	g_free(buf);
 	if (debug) printf(_("GQview running: %s\n"), cmd);
 	system(cmd);
+
 	g_free(cmd);
 }
 
-void start_editor_from_list(gint n)
-{
-	GList *list;
-
-	list = file_get_selected_list();
-	if (!list) return;
-	start_editor_from_path_list(n, list);
-	path_list_free(list);
-}
-
 /*
  *-----------------------------------------------------------------------------
  * keyboard functions
@@ -223,138 +213,6 @@ void keyboard_scroll_calc(gint *x, gint *y, GdkEventKey *event)
 	*y = *y * delta;
 }
 
-gint key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
-{
-	gint stop_signal = FALSE;
-	gint x = 0;
-	gint y = 0;
-
-	if (GTK_WIDGET_HAS_FOCUS(path_entry))
-		{
-		if (event->keyval == GDK_Escape)
-			gtk_entry_set_text(GTK_ENTRY(path_entry), current_path);
-		return stop_signal;
-		}
-
-	if (full_screen_window || GTK_WIDGET_HAS_FOCUS(main_image->widget))
-		{
-		switch (event->keyval)
-			{
-			case GDK_Left: case GDK_KP_Left:
-				x -= 1;
-				stop_signal = TRUE;
-				break;
-			case GDK_Right: case GDK_KP_Right:
-				x += 1;
-				stop_signal = TRUE;
-				break;
-			case GDK_Up: case GDK_KP_Up:
-				y -= 1;
-				stop_signal = TRUE;
-				break;
-			case GDK_Down: case GDK_KP_Down:
-				y += 1;
-				stop_signal = TRUE;
-				break;
-			case GDK_BackSpace:
-			case 'B': case 'b':
-				main_image_prev();
-				stop_signal = TRUE;
-				break;
-			case GDK_space:
-				main_image_next();
-				stop_signal = TRUE;
-				break;
-			}
-		}
-
-	if ( !(event->state & GDK_CONTROL_MASK) )
-	    switch (event->keyval)
-		{
-		case '+': case GDK_KP_Add:
-			main_image_adjust_zoom(get_zoom_increment());
-			stop_signal = TRUE;
-			break;
-		case GDK_KP_Subtract:
-			main_image_adjust_zoom(-get_zoom_increment());
-			stop_signal = TRUE;
-			break;
-		case GDK_KP_Multiply:
-			main_image_set_zoom(0.0);
-			stop_signal = TRUE;
-			break;
-		case GDK_KP_Divide: case '1':
-			main_image_set_zoom(1.0);
-			stop_signal = TRUE;
-			break;
-		case '2':
-			main_image_set_zoom(2.0);
-			stop_signal = TRUE;
-			break;
-		case '3':
-			main_image_set_zoom(3.0);
-			stop_signal = TRUE;
-			break;
-		case '4':
-			main_image_set_zoom(4.0);
-			stop_signal = TRUE;
-			break;
-		case GDK_Page_Up: case GDK_KP_Page_Up:
-			main_image_prev();
-			stop_signal = TRUE;
-			break;
-		case GDK_Page_Down: case GDK_KP_Page_Down:
-			main_image_next();
-			stop_signal = TRUE;
-			break;
-		case GDK_Home: case GDK_KP_Home:
-			main_image_first();
-			stop_signal = TRUE;
-			break;
-		case GDK_End: case GDK_KP_End:
-			main_image_last();
-			stop_signal = TRUE;
-			break;
-		case GDK_Delete: case GDK_KP_Delete:
-			if (enable_delete_key)
-				{
-				file_util_delete(NULL, file_get_selected_list());
-				stop_signal = TRUE;
-				}
-			break;
-		case GDK_Escape:
-			interrupt_thumbs();
-			stop_signal = TRUE;
-			break;
-		case 'P': case 'p':
-			main_image_slideshow_pause_toggle();
-			break;
-		case 'Q': case 'q':
-			if (event->state == 0 || (event->state & GDK_MODIFIER_MASK) == GDK_LOCK_MASK)
-				{
-				exit_gqview();
-				return FALSE;
-				}
-			break;
-		}
-
-	if (event->state & GDK_SHIFT_MASK)
-		{
-		x *= 3;
-		y *= 3;
-		}
-
-	if (x != 0 || y!= 0)
-		{
-		keyboard_scroll_calc(&x, &y, event);
-		main_image_scroll(x, y);
-		}
-
-	if (stop_signal) gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
-
-	return stop_signal;
-}
-
 /*
  *-----------------------------------------------------------------------------
  * command line parser (private) hehe, who needs popt anyway?
@@ -394,7 +252,7 @@ static void parse_command_line(int argc, char *argv[], gchar **path, gchar **fil
 		while (i < argc)
 			{
 			const gchar *cmd_line = argv[i];
-			gchar *cmd_all = g_strconcat(base_dir, "/", cmd_line, NULL);
+			gchar *cmd_all = concat_dir_and_file(base_dir, cmd_line);
 
 			if (!*path && cmd_line[0] == '/' && isdir(cmd_line))
 				{
@@ -568,9 +426,17 @@ static void exit_gqview_final(void)
 {
 	gchar *path;
 
-	gdk_window_get_root_origin (mainwindow->window, &main_window_x, &main_window_y);
-	gdk_window_get_size(mainwindow->window, &main_window_w, &main_window_h);
+	layout_geometry_get(NULL, &main_window_x, &main_window_y,
+			    &main_window_w, &main_window_h);
 
+	layout_geometry_get_dividers(NULL, &window_hdivider_pos, &window_vdivider_pos);
+
+	layout_views_get(NULL, &layout_view_tree, &layout_view_icons);
+
+	thumbnails_enabled = layout_thumb_get(NULL);
+	layout_sort_get(NULL, &file_sort_method, &file_sort_ascending);
+
+#if 0
 	if (!toolwindow || (toolwindow && GTK_WIDGET_VISIBLE(toolwindow)) )
 		{
 		main_window_vdivider_pos = dir_clist->allocation.height;
@@ -581,6 +447,8 @@ static void exit_gqview_final(void)
 		gdk_window_get_root_origin (toolwindow->window, &float_window_x, &float_window_y);
 		gdk_window_get_size(toolwindow->window, &float_window_w, &float_window_h);
 		}
+#endif
+
 	save_options();
 	keys_save();
 
@@ -628,7 +496,7 @@ static gint exit_confirm_dlg(void)
 
 void exit_gqview(void)
 {
-	main_image_full_screen_stop();
+	layout_image_full_screen_stop(NULL);
 
 	if (exit_confirm_dlg()) return;
 
@@ -637,6 +505,8 @@ void exit_gqview(void)
 
 int main (int argc, char *argv[])
 {
+	LayoutWindow *lw;
+	gchar *path = NULL;
 	gchar *cmd_path = NULL;
 	gchar *cmd_file = NULL;
 	GList *cmd_list = NULL;
@@ -655,46 +525,20 @@ int main (int argc, char *argv[])
 	check_for_home_path(GQVIEW_RC_DIR_THUMBS);
 	check_for_home_path(GQVIEW_RC_DIR_COLLECTIONS);
 
-	/* backwards compatibility */
-	buf = g_strconcat(homedir(), "/.gqviewrc", NULL);
-	if (isfile(buf))
-		{
-		gchar *new_buf;
-		new_buf = g_strconcat(homedir(), "/", GQVIEW_RC_DIR, "/", RC_FILE_NAME, NULL);
-		printf("moving old location of .gqviewrc to new location:\n%s\n", new_buf);
-		if (rename(buf, new_buf) != 0)
-			{
-			printf("Warning: move of .gqviewrc failed!\n");
-			}
-		g_free(new_buf);
-		}
-	g_free(buf);
-
-	buf = g_strconcat(homedir(), "/.gqview_thmb", NULL);
-	if (isdir(buf))
-		{
-		gchar *new_buf;
-		new_buf = g_strconcat(homedir(), "/", GQVIEW_RC_DIR_THUMBS, NULL);
-		printf("moving old location of .gqview_thmb to new location:\n%s\n", new_buf);
-		if (rename(buf, new_buf) != 0)
-			{
-			printf("Warning: move of .gqview_thmb failed!\n");
-			}
-		g_free(new_buf);
-		}
-	g_free(buf);
+	printf("GQview %s\nThis is a beta release, in active development.\nThings may break from version to version.\nWant stability? Use a 1.0 version. YOU WERE WARNED!\n", VERSION);
 
 	gtk_init (&argc, &argv);
 
 	gdk_rgb_init();
 
-
 	/* push the correct color depths to gtk, (for 8-bit psuedo color displays)
 	 * they should be popped, too, I guess...
 	 */
 	gtk_widget_push_visual(gdk_rgb_get_visual());
 	gtk_widget_push_colormap(gdk_rgb_get_cmap());
 
+	layout_order = g_strdup("123");
+
 	setup_default_options();
 	load_options();
 	keys_load();
@@ -706,19 +550,23 @@ int main (int argc, char *argv[])
 	parse_command_line(argc, argv, &cmd_path, &cmd_file, &cmd_list, &collection_list);
 
 	if (cmd_path)
-		current_path = g_strdup(cmd_path);
+		{
+		path = g_strdup(cmd_path);
+		}
 	else if (startup_path_enable && startup_path && isdir(startup_path))
-		current_path = g_strdup(startup_path);
+		{
+		path = g_strdup(startup_path);
+		}
 	else
-		current_path = get_current_dir();
+		{
+		path = get_current_dir();
+		}
 
-	create_main_window();
-	update_edit_menus(mainwindow_accel_grp);
-	rebuild_file_filter();
-	filelist_set_sort_method(file_sort_method, FALSE);
-	filelist_refresh();
+	filter_rebuild();
 
-	init_dnd();
+	lw = layout_new(NULL);
+	layout_sort_set(lw, file_sort_method, file_sort_ascending);
+	layout_set_path(lw, path);
 
 	if (cmd_list)
 		{
@@ -751,23 +599,24 @@ int main (int argc, char *argv[])
 			work = work->next;
 			}
 
-		if (cd->list) main_image_change_to_from_collection(cd, cd->list->data);
-#if 0
+		if (cd->list) layout_image_set_collection(lw, cd, cd->list->data);
+
 		/* mem leak, we never unref this collection when !startup_command_line_collection
 		 * (the image view of the main window does not hold a ref to the collection)
 		 * this is sort of unavoidable, for if it did hold a ref, next/back
 		 * may not work as expected when closing collection windows.
+		 *
+		 * collection_unref(cd);
 		 */
-		collection_unref(cd);
-#endif
+
 		}
 	else if (cmd_file)
 		{
-		filelist_change_to_full_path(cmd_file);
+		layout_set_path(lw, cmd_file);
 		}
 	else
 		{
-		main_image_change_to(NULL, NULL);
+		layout_image_set_with_ahead(lw, NULL, NULL);
 		}
 
 	if (collection_list)
@@ -788,12 +637,12 @@ int main (int argc, char *argv[])
 	g_free(cmd_file);
 	path_list_free(cmd_list);
 	path_list_free(collection_list);
+	g_free(path);
 
-	if (startup_full_screen) main_image_full_screen_toggle();
-	if (startup_in_slideshow) main_image_slideshow_start();
+	if (startup_full_screen) layout_image_full_screen_start(lw);
+	if (startup_in_slideshow) layout_image_slideshow_start(lw);
 
 	gtk_main ();
 	return 0;
 }
 
-
