@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -15,7 +15,8 @@
 
 #include "cache_maint.h"
 #include "filelist.h"
-#include "menu.h"
+#include "layout_config.h"
+#include "layout_util.h"
 #include "ui_tabcomp.h"
 #include "ui_utildlg.h"
 
@@ -102,6 +103,11 @@ static GtkWidget *custom_filter_entry;
 static GtkWidget *editor_name_entry[8];
 static GtkWidget *editor_command_entry[8];
 
+static GtkWidget *layout_widget;
+
+static gint tree_descend_subdirs_c;
+
+
 /*
  *-----------------------------------------------------------------------------
  * option widget callbacks (private)
@@ -110,7 +116,7 @@ static GtkWidget *editor_command_entry[8];
 
 static void startup_path_set_current(GtkWidget *widget, gpointer data)
 {
-	gtk_entry_set_text(GTK_ENTRY(startup_path_entry), current_path);
+	gtk_entry_set_text(GTK_ENTRY(startup_path_entry), layout_get_path(NULL));
 }
 
 static void slideshow_delay_cb(GtkObject *adj, gpointer data)
@@ -176,6 +182,7 @@ static void cache_clear_cb(GtkWidget *widget, gpointer data)
 static void config_window_apply(void)
 {
 	gchar *buf;
+	gint new_style;
 	gint i;
 	gint refresh = FALSE;
 
@@ -191,7 +198,7 @@ static void config_window_apply(void)
 		buf = gtk_entry_get_text(GTK_ENTRY(editor_command_entry[i]));
 		if (buf && strlen(buf) > 0) editor_command[i] = g_strdup(buf);
 		}
-	update_edit_menus(mainwindow_accel_grp);
+	layout_edit_update_all();
 
 	g_free(startup_path);
 	startup_path = NULL;
@@ -268,10 +275,30 @@ static void config_window_apply(void)
 
 	place_dialogs_under_mouse = place_dialogs_under_mouse_c;
 
+	tree_descend_subdirs = tree_descend_subdirs_c;
+
+	buf = layout_config_get(layout_widget, &new_style);
+
+	if (new_style != layout_style ||
+	    (buf == NULL) != (layout_order == NULL) ||
+	    !layout_order ||
+	    strcmp(buf, layout_order) != 0)
+		{
+		if (refresh) filter_rebuild();
+		refresh = FALSE;
+
+		g_free(layout_order);
+		layout_order = buf;
+
+		layout_style = new_style;
+
+		layout_styles_update();
+		}
+
 	if (refresh)
 		{
-		rebuild_file_filter();
-		filelist_refresh();
+		filter_rebuild();
+		layout_refresh(NULL);
 		}
 }
 
@@ -804,6 +831,20 @@ static void config_window_create(void)
 	add_check_button(place_dialogs_under_mouse, &place_dialogs_under_mouse_c,
 			 _("Place dialogs under mouse"), vbox);
 
+	add_check_button(tree_descend_subdirs, &tree_descend_subdirs_c,
+			 _("Descend folders in tree view"), vbox);
+
+	frame = gtk_frame_new(_("Layout"));
+	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
+	gtk_widget_show(frame);
+
+	layout_widget = layout_config_new();
+	layout_config_set(layout_widget, layout_style, layout_order);
+	gtk_container_add(GTK_CONTAINER(frame), layout_widget);
+	gtk_widget_show(layout_widget);
+
+
 	/* filtering tab */
 
 	frame = gtk_frame_new(NULL);
@@ -1038,7 +1079,7 @@ void show_about_window(void)
 	gdk_pixmap_unref(pixmap);
 	if (mask) gdk_bitmap_unref(mask);
 
-	buf = g_strdup_printf(_("GQview %s\n\nCopyright (c) 2001 by John Ellis\nhttp://gqview.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), VERSION);
+	buf = g_strdup_printf(_("GQview %s\n\nCopyright (c) 2002 by John Ellis\nhttp://gqview.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), VERSION);
 	label = gtk_label_new(buf);
 	g_free(buf);
 
@@ -1049,5 +1090,3 @@ void show_about_window(void)
 	gtk_widget_show(about);
 }
 
-
-
