@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -144,6 +144,16 @@ void save_options(void)
 	fprintf(f,"\n");
 	fprintf(f,"##### General Options #####\n\n");
 
+	write_int_option(f, "layout_style", layout_style);
+	write_char_option(f, "layout_order", layout_order);
+	fprintf(f,"\n");
+	write_bool_option(f, "layout_view_as_icons", layout_view_icons);
+	write_bool_option(f, "layout_view_as_tree", layout_view_tree);
+	fprintf(f,"\n");
+
+	write_bool_option(f, "tree_descend_folders", tree_descend_subdirs);
+	fprintf(f,"\n");
+
 	write_bool_option(f, "enable_startup_path", startup_path_enable);
 	write_char_option(f, "startup_path", startup_path);
 	fprintf(f,"\n");
@@ -254,7 +264,8 @@ void save_options(void)
 	write_int_option(f, "float_window_y", float_window_y);
 	write_int_option(f, "float_window_width", float_window_w);
 	write_int_option(f, "float_window_height", float_window_h);
-	write_int_option(f, "file_divider_position", main_window_vdivider_pos);
+	write_int_option(f, "divider_position_h", window_hdivider_pos);
+	write_int_option(f, "divider_position_v", window_vdivider_pos);
 
 	fprintf(f,"######################################################################\n");
 	fprintf(f,"#                      end of GQview config file                     #\n");
@@ -313,6 +324,18 @@ void load_options(void)
 
 		/* general options */
 
+		layout_style = read_int_option(f, option,
+			"layout_style", value, layout_style);
+		layout_order = read_char_option(f, option,
+			"layout_order", value, layout_order);
+		layout_view_icons = read_bool_option(f, option,
+			"layout_view_as_icons", value, layout_view_icons);
+		layout_view_tree = read_bool_option(f, option,
+			"layout_view_as_tree", value, layout_view_tree);
+
+		tree_descend_subdirs = read_bool_option(f, option,
+			"tree_descend_folders", value, tree_descend_subdirs);
+
 		startup_path_enable = read_bool_option(f, option,
 			"enable_startup_path", value, startup_path_enable);
 		startup_path = read_char_option(f, option,
@@ -506,8 +529,10 @@ void load_options(void)
 			"float_window_width", value, float_window_w);
 		float_window_h = read_int_option(f, option,
 			"float_window_height", value, float_window_h);
-		main_window_vdivider_pos = read_int_option(f, option,
-			"file_divider_position", value, main_window_vdivider_pos);
+		window_hdivider_pos = read_int_option(f, option,
+			"divider_position_h", value, window_hdivider_pos);
+		window_vdivider_pos = read_int_option(f, option,
+			"divider_position_v", value, window_vdivider_pos);
 
 		}
 
@@ -530,4 +555,3 @@ void load_options(void)
 
 }
 
-
