@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -15,8 +15,8 @@
 #include "image.h"
 #include "slideshow.h"
 
-#include "filelist.h"
-#include "img-main.h"
+#include "layout.h"
+#include "layout_image.h"
 #include "ui_fileops.h"
 
 
@@ -31,7 +31,7 @@ void slideshow_free(SlideShowData *ss)
 
 	if (ss->path_list) path_list_free(ss->path_list);
 	if (ss->cd) collection_unref(ss->cd);
-	g_free(ss->filelist_path);
+	g_free(ss->layout_path);
 
 	g_list_free(ss->list);
 	g_list_free(ss->list_done);
@@ -47,12 +47,7 @@ static GList *generate_list(SlideShowData *ss)
 
 	if (ss->from_selection)
 		{
-		GList *work = GTK_CLIST(file_clist)->selection;
-		while(work)
-			{
-			list = g_list_prepend(list, work->data);
-			work = work->next;
-			}
+		list = layout_selection_list_by_index(ss->layout);
 		}
 	else
 		{
@@ -60,9 +55,9 @@ static GList *generate_list(SlideShowData *ss)
 		for(i = 0; i < ss->slide_count; i++)
 			{
 			list = g_list_prepend(list, GINT_TO_POINTER(i));
+			list = g_list_reverse(list);
 			}
 		}
-	list = g_list_reverse(list);
 
 	return list;
 }
@@ -121,6 +116,7 @@ static void slideshow_list_init(SlideShowData *ss, gint start_index)
 gint slideshow_should_continue(SlideShowData *ss)
 {
 	const gchar *imd_path;
+	const gchar *path;
 
 	imd_path = image_get_path(ss->imd);
 
@@ -137,11 +133,14 @@ gint slideshow_should_continue(SlideShowData *ss)
 			return FALSE;
 		}
 
-	if (current_path && ss->filelist_path &&
-	    strcmp(current_path, ss->filelist_path) == 0)
+	if (!ss->layout) return FALSE;
+	path = layout_get_path(ss->layout);
+
+	if (path && ss->layout_path &&
+	    strcmp(path, ss->layout_path) == 0)
 		{
-		if (ss->from_selection && ss->slide_count == file_selection_count()) return TRUE;
-		if (!ss->from_selection && ss->slide_count == file_count()) return TRUE;
+		if (ss->from_selection && ss->slide_count == layout_selection_count(ss->layout, NULL)) return TRUE;
+		if (!ss->from_selection && ss->slide_count == layout_list_count(ss->layout, NULL)) return TRUE;
 		}
 
 	return FALSE;
@@ -192,16 +191,17 @@ static gint slideshow_step(SlideShowData *ss, gint forward)
 		}
 	else
 		{
-		ss->slide_path = file_get_path(row);
+		ss->slide_path = g_strdup(layout_list_get_path(ss->layout, row));
 
 		if (ss->from_selection)
 			{
 			image_change_path(ss->imd, ss->slide_path, image_zoom_get_default(ss->imd, zoom_mode));
-			update_status_label(NULL);
+	/* FIXME: is this really needed ? */
+			layout_status_update_info(ss->layout, NULL);
 			}
 		else
 			{
-			file_image_change_to(row);
+			layout_image_set_index(ss->layout, row);
 			}
 		}
 
@@ -241,9 +241,9 @@ static gint slideshow_step(SlideShowData *ss, gint forward)
 			info = g_list_nth_data(ss->cd->list, r);
 			if (info) image_prebuffer_set(ss->imd, info->path);
 			}
-		else
+		else if (ss->from_selection)
 			{
-			image_prebuffer_set(ss->imd, file_get_path(r));
+			image_prebuffer_set(ss->imd, layout_list_get_path(ss->layout, r));
 			}
 		}
 
@@ -302,14 +302,15 @@ void slideshow_prev(SlideShowData *ss)
 	slideshow_timer_reset(ss, TRUE);
 }
 
-static SlideShowData *real_slideshow_start(ImageWindow *imd, GList *path_list, CollectionData *cd,
-					   void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data,
-					   gint start_point, CollectInfo *start_info)
+static SlideShowData *real_slideshow_start(ImageWindow *imd, LayoutWindow *lw,
+					   GList *path_list, gint start_point,
+					   CollectionData *cd, CollectInfo *start_info,
+					   void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data)
 {
 	SlideShowData *ss;
 	gint start_index = -1;
 
-	if (!path_list && !cd && file_count() < 1) return NULL;
+	if (!path_list && !cd && layout_list_count(lw, NULL) < 1) return NULL;
 
 	ss = g_new0(SlideShowData, 1);
 
@@ -317,7 +318,8 @@ static SlideShowData *real_slideshow_start(ImageWindow *imd, GList *path_list, C
 
 	ss->path_list = path_list;
 	ss->cd = cd;
-	ss->filelist_path = NULL;
+	ss->layout = lw;
+	ss->layout_path = NULL;
 
 	ss->list = NULL;
 	ss->list_done = NULL;
@@ -344,15 +346,15 @@ static SlideShowData *real_slideshow_start(ImageWindow *imd, GList *path_list, C
 			start_index = g_list_index(ss->cd->list, start_info);
 			}
 		}
-	else if (imd == main_image)
+	else
 		{
-		/* only the main window can use this method */
+		/* layout method */
 
-		ss->slide_count = file_selection_count();
-		ss->filelist_path = g_strdup(current_path);
+		ss->slide_count = layout_selection_count(ss->layout, NULL);
+		ss->layout_path = g_strdup(layout_get_path(ss->layout));
 		if (ss->slide_count < 2)
 			{
-			ss->slide_count = file_count();
+			ss->slide_count = layout_list_count(ss->layout, NULL);
 			if (!slideshow_random && start_point >= 0 && start_point < ss->slide_count)
 				{
 				start_index = start_point;
@@ -363,11 +365,6 @@ static SlideShowData *real_slideshow_start(ImageWindow *imd, GList *path_list, C
 			ss->from_selection = TRUE;
 			}
 		}
-	else
-		{
-		g_free(ss);
-		return NULL;
-		}
 
 	slideshow_list_init(ss, start_index);
 
@@ -387,21 +384,20 @@ static SlideShowData *real_slideshow_start(ImageWindow *imd, GList *path_list, C
 SlideShowData *slideshow_start_from_path_list(ImageWindow *imd, GList *list,
 					      void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data)
 {
-	return real_slideshow_start(imd, list, NULL, stop_func, stop_data, -1, NULL);
+	return real_slideshow_start(imd, NULL, list, -1, NULL, NULL, stop_func, stop_data);
 }
 
 SlideShowData *slideshow_start_from_collection(ImageWindow *imd, CollectionData *cd,
 					       void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data,
 					       CollectInfo *start_info)
 {
-	return real_slideshow_start(imd, NULL, cd, stop_func, stop_data, -1, start_info);
+	return real_slideshow_start(imd, NULL, NULL, -1, cd, start_info, stop_func, stop_data);
 }
 
-SlideShowData *slideshow_start(ImageWindow *imd,
-			       void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data,
-			       gint start_point)
+SlideShowData *slideshow_start(ImageWindow *imd, LayoutWindow *lw, gint start_point,
+			       void (*stop_func)(SlideShowData *, gpointer), gpointer stop_data)
 {
-	return real_slideshow_start(imd, NULL, NULL, stop_func, stop_data, start_point, NULL);
+	return real_slideshow_start(imd, lw, NULL, start_point, NULL, NULL, stop_func, stop_data);
 }
 
 gint slideshow_paused(SlideShowData *ss)
