@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -200,12 +200,10 @@ static void dest_populate(Dest_Data *dd, const gchar *path)
 			if (p - 1 != filepath) p--;
 			p[0] = '\0';
 			}
-		else if (strcmp(path, "/") == 0)
-			{
-			filepath = g_strconcat("/", list->data, NULL);
-			}
 		else
-			filepath = g_strconcat(path, "/", list->data, NULL);
+			{
+			filepath = concat_dir_and_file(path, list->data);
+			}
 		
 		buf[0] = list->data;
 		row = gtk_clist_append(GTK_CLIST(dd->d_clist),buf);
@@ -229,7 +227,9 @@ static void dest_populate(Dest_Data *dd, const gchar *path)
         	        {
 			gint row;
 			gchar *filepath;
-			filepath = g_strconcat(path, "/", list->data, NULL);
+			const gchar *name = list->data;
+
+			filepath = concat_dir_and_file(path, name);
 		
 			buf[0] = list->data;
 			row = gtk_clist_append(GTK_CLIST(dd->f_clist),buf);
@@ -299,7 +299,7 @@ static gint dest_row_edit_rename_cb(ClistEditData *ced, const gchar *old, const
 	if (!old_path) return FALSE;
 
 	buf = remove_level_from_path(old_path);
-	new_path = g_strconcat(buf, "/", new, NULL);
+	new_path = concat_dir_and_file(buf, new);
 	g_free(buf);
 
 	if (isname(new_path))
@@ -504,7 +504,7 @@ static void dest_new_dir_cb(GtkWidget *widget, gpointer data)
 		}
 	else
 		{
-		buf = g_strconcat(dd->path, "/", _("New Directory"), NULL);
+		buf = concat_dir_and_file(dd->path, _("New Directory"));
 		path = unique_filename(buf, NULL, " ", FALSE);
 		g_free(buf);
 		}
