@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -36,6 +36,7 @@
 /* define this to enable a pop-up menu that shows possible matches
  * #define TAB_COMPLETION_ENABLE_POPUP_MENU
  */
+#define TAB_COMPLETION_ENABLE_POPUP_MENU 1
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
 #include "ui_menu.h"
@@ -449,11 +450,20 @@ static void tab_completion_popup_cb(GtkWidget *widget, gpointer data)
 	ptr = td->dir_path + strlen(td->dir_path) - 1;
 	buf = g_strconcat(td->dir_path, (ptr[0] == '/') ? "" : "/", name, NULL);
 	gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+	gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(buf));
 	g_free(buf);
 
 	tab_completion_emit_tab_signal(td);
 }
 
+/*
+ * MAGIC_OFFSET: No simple way to determine frame size of menu.
+ * MAX: Limit popup menu items to a sane number, will be fixed when a list is used instead.
+ */
+
+#define TAB_COMP_POPUP_MAGIC_OFFSET 3
+#define TAB_COMP_POPUP_MAX 64
+
 static void tab_completion_popup_pos_cb(GtkMenu *menu, gint *x, gint *y, gpointer data)
 {
 	TabCompData *td = data;
@@ -465,7 +475,7 @@ static void tab_completion_popup_pos_cb(GtkMenu *menu, gint *x, gint *y, gpointe
 	*y += height;
 
 	*x += GTK_ENTRY(td->entry)->char_offset[GTK_EDITABLE(td->entry)->current_pos];
-	*x -= GTK_ENTRY(td->entry)->scroll_offset;
+	*x -= GTK_ENTRY(td->entry)->scroll_offset + TAB_COMP_POPUP_MAGIC_OFFSET;
 }
 
 static void tab_completion_popup_list(TabCompData *td, GList *list)
@@ -475,6 +485,7 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 	GdkEvent *event;
 	guint32 etime;
 	gint ebutton;
+	gint count = 0;
 
 	if (!list) return;
 
@@ -488,7 +499,7 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 	menu = popup_menu_short_lived();
 
 	work = list;
-	while (work)
+	while (work && count < TAB_COMP_POPUP_MAX)
 		{
 		gchar *name = work->data;
 		GtkWidget *item;
@@ -497,6 +508,7 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 		gtk_object_set_data(GTK_OBJECT(item), "tab_completion_data", td);
 
 		work = work->next;
+		count++;
 		}
 
 	gtk_signal_connect(GTK_OBJECT(menu), "key_press_event",
