@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2001 John Ellis
+ * (C) 2002 John Ellis
  *
  * Author: John Ellis
  *
@@ -17,8 +17,8 @@
 #include "cache_maint.h"
 #include "collect.h"
 #include "dupe.h"
-#include "filelist.h"
 #include "image.h"
+#include "layout.h"
 #include "ui_fileops.h"
 #include "ui_tabcomp.h"
 
@@ -32,7 +32,7 @@
 
 void file_maint_renamed(const gchar *source, const gchar *dest)
 {
-	file_is_renamed(source, dest);
+	layout_maint_renamed(source, dest);
 	collection_maint_renamed(source, dest);
 	dupe_maint_renamed(source, dest);
 	cache_maint_moved(source, dest);
@@ -41,7 +41,7 @@ void file_maint_renamed(const gchar *source, const gchar *dest)
 /* under most cases ignore_list should be NULL */
 void file_maint_removed(const gchar *path, GList *ignore_list)
 {
-	file_is_gone(path, ignore_list);
+	layout_maint_removed(path, ignore_list);
 	collection_maint_removed(path);
 	dupe_maint_removed(path);
 	cache_maint_removed(path);
@@ -50,7 +50,7 @@ void file_maint_removed(const gchar *path, GList *ignore_list)
 /* special case for correct main window behavior */
 void file_maint_moved(const gchar *source, const gchar *dest, GList *ignore_list)
 {
-	file_is_moved(source, dest, ignore_list);
+	layout_maint_moved(source, dest, ignore_list);
 	collection_maint_renamed(source, dest);
 	dupe_maint_renamed(source, dest);
 	cache_maint_moved(source, dest);
@@ -237,7 +237,7 @@ GenericDialog *file_util_warning_dialog(const gchar *title, const gchar *message
  * Multi file move
  */
 
-static FileDataMult *file_data_multiple_new(GList *source_list, gchar *dest, gint copy)
+static FileDataMult *file_data_multiple_new(GList *source_list, const gchar *dest, gint copy)
 {
 	FileDataMult *fdm = g_new0(FileDataMult, 1);
 	fdm->confirm_all = FALSE;
@@ -301,7 +301,7 @@ static void file_util_move_multiple(FileDataMult *fdm)
 			{
 			GList *work = fdm->source_next;
 			fdm->source = work->data;
-			fdm->dest = g_strconcat(fdm->dest_base, "/", filename_from_path(fdm->source), NULL);
+			fdm->dest = concat_dir_and_file(fdm->dest_base, filename_from_path(fdm->source));
 			fdm->source_next = work->next;
 			}
 
@@ -409,7 +409,7 @@ static void file_util_move_multiple(FileDataMult *fdm)
  * Single file move
  */
 
-static FileDataSingle *file_data_single_new(gchar *source, gchar *dest, gint copy)
+static FileDataSingle *file_data_single_new(const gchar *source, const gchar *dest, gint copy)
 {
 	FileDataSingle *fds = g_new0(FileDataSingle, 1);
 	fds->confirmed = FALSE;
@@ -520,7 +520,7 @@ static void file_util_move_do(FileDialog *fd)
 		{
 		if (isdir(fd->dest_path))
 			{
-			gchar *buf = g_strconcat(fd->dest_path, "/", filename_from_path(fd->source_path), NULL);
+			gchar *buf = concat_dir_and_file(fd->dest_path, filename_from_path(fd->source_path));
 			gtk_entry_set_text(GTK_ENTRY(fd->entry), buf);
 			g_free(buf);
 			}
@@ -630,6 +630,58 @@ void file_util_copy(const gchar *source_path, GList *source_list, const gchar *d
 	real_file_util_move(source_path, source_list, dest_path, TRUE);
 }
 
+void file_util_move_simple(GList *list, const gchar *dest_path)
+{
+	if (!list) return;
+	if (!dest_path)
+		{
+		path_list_free(list);
+		return;
+		}
+
+	if (!list->next)
+		{
+		const gchar *source;
+		gchar *dest;
+
+		source = list->data;
+		dest = concat_dir_and_file(dest_path, filename_from_path(source));
+
+		file_util_move_single(file_data_single_new(source, dest, FALSE));
+		g_free(dest);
+		path_list_free(list);
+		return;
+		}
+
+	file_util_move_multiple(file_data_multiple_new(list, dest_path, FALSE));
+}
+
+void file_util_copy_simple(GList *list, const gchar *dest_path)
+{
+	if (!list) return;
+	if (!dest_path)
+		{
+		path_list_free(list);
+		return;
+		}
+
+	if (!list->next)
+		{
+		const gchar *source;
+		gchar *dest;
+
+		source = list->data;
+		dest = concat_dir_and_file(dest_path, filename_from_path(source));
+
+		file_util_move_single(file_data_single_new(source, dest, TRUE));
+		g_free(dest);
+		path_list_free(list);
+		return;
+		}
+
+	file_util_move_multiple(file_data_multiple_new(list, dest_path, TRUE));
+}
+
 /*
  *--------------------------------------------------------------------------
  * Delete routines
@@ -891,7 +943,7 @@ static void file_util_rename_multiple_cb(FileDialog *fd, gpointer data)
 	base = remove_level_from_path(fd->source_path);
 
 	g_free(fd->dest_path);
-	fd->dest_path = g_strconcat(base, "/", name, NULL);
+	fd->dest_path = concat_dir_and_file(base, name);
 	g_free(base);
 
 	if (strlen(name) == 0 || strcmp(fd->source_path, fd->dest_path) == 0)
@@ -1062,7 +1114,7 @@ static void file_util_rename_single_cb(FileDialog *fd, gpointer data)
 	gchar *path;
 
 	name = gtk_entry_get_text(GTK_ENTRY(fd->entry));
-	path = g_strconcat(fd->dest_path, "/", name, NULL);
+	path = concat_dir_and_file(fd->dest_path, name);
 
 	if (strlen(name) == 0 || strcmp(fd->source_path, path) == 0)
 		{
@@ -1137,7 +1189,7 @@ static void file_util_create_dir_do(const gchar *base, const gchar *name)
 {
 	gchar *path;
 
-	path = g_strconcat(base, "/", name, NULL);
+	path = concat_dir_and_file(base, name);
 
 	if (isdir(path))
 		{
@@ -1161,12 +1213,14 @@ static void file_util_create_dir_do(const gchar *base, const gchar *name)
 			}
 		else
 			{
+#if 0
 			if (strcmp(base, current_path) == 0)
 				{
 				gchar *buf = g_strdup(current_path);
 				filelist_change_to(buf);
 				g_free(buf);
 				}
+#endif
 			}
 		}
 
@@ -1226,7 +1280,3 @@ void file_util_create_dir(const gchar *path)
 	gtk_widget_show(GENERIC_DIALOG(fd)->dialog);
 }
 
-
-
-
-
